options = {
    "newChannel": {
        "name": "",
        "id": 0,
        "type": "",
        "category": "",
        "categoryid": 0,
        "guild": "",
        "nsfw": "",
        "delay": 0,
        "created": ""
    },
    "oldChannel": {
        "name": "",
        "id": 0,
        "type": "",
        "category": "",
        "categoryid": 0,
        "guild": "",
        "nsfw": "",
        "delay": 0,
        "created": ""
    },
    "memberJoined": {
        "id": 0,
        'guildid': 0
    },
    "deletedChannel": {
        "name": "",
        "id": 0,
        "type": "",
        "category": "",
        "categoryid": 0,
        "guild": "",
        "nsfw": "",
        "delay": 0,
        "created": ""
    },
    "reactionAdded": {
        "name": "",
        "emoji": "",
        "id": 0,
        "bot_reacted": '',
        "users_reacted": [],
        "count": 0,
        "username": '',
        'msgid': 0,
        'msgauthorid': 0,
        'msgauthorname': '',
        "userid": 0,
    },
    "reactionRemoved": {
        "name": "",
        "emoji": "",
        "id": 0,
        "bot_reacted": '',
        "users_reacted": [],
        "count": 0,
        "username": '',
        'msgid': 0,
        'msgauthorid': 0,
        'msgauthorname': '',
        "userid": 0,
    }
}
