all_Funcs = [
    "$If",
    "$ElIf",
    "$addButton",
    "$buttonSend",
    "$authorID",
    "$botAvatar",
    "$botGuilds",
    "$botID",
    "$botMention",
    "$botName",
    "$channelCategoryID",
    "$channelCategoryName",
    "$channelChangedRoles",
    "$channelCreated",
    "$channelDelay",
    "$channelID",
    "$channelMention",
    "$channelName",
    "$channelNsfw",
    "$channelPosition",
    "$channelType",
    "$channelURL",
    "$charmAI",
    "$console",
    "$count",
    "$defer",
    "$deleteMessage",
    "$deletedChannel",
    "$divide",
    "$editMessage",
    "$get",
    "$getJson",
    "$getVar",
    "$guildID",
    "$guildName",
    "$guildTextChannels",
    "$hasPerm",
    "$let",
    "$memberJoined",
    "$mentions",
    "$message",
    "$messageAuthor",
    "$messageContent",
    "$messageID",
    "$multi",
    "$oldChannel",
    "$onlyIf",
    "$ping",
    "$pyEval",
    "$purge",
    "$reactionAdded",
    "$reactionRemoved",
    "$sendMessage",
    "$sendDM",
    "$sendEmbed",
    "$setServerVar",
    "$setUserVar",
    "$setVar",
    "$slashSend",
    "$sub",
    "$sum",
    "$userMention",
    "$userName",
    "$userID",
    "$wait",
    "$waitMessage",
    "$waitReaction"
]

date_funcs = ["$channelCreated"]

ifse = ["$If", "$ElIf"]

no_arg_Funcs = ["$botName",
                "$botID",
                "$authorID",
                "$channelID",
                "$guildID",
                "$ping",
                "$botGuilds",
                "$botAvatar",
                "$botMention",
                "$messageID",
                "$message",
                "$defer"]

newline_char = "*n*"
